from __future__ import annotations

from ..enka.build import BaseBuild
from .character import Agent

__all__ = ("Build",)


class Build(BaseBuild[Agent]):
    """Represents a ZZZ build.

    Attributes:
        id: The build's ID.
        name: The build's name.
        order: The build's order.
        live: Whether the build is live.
        character_id: The build's character ID.
        character: The build's character data.
    """



from __future__ import annotations

from decimal import Decimal
from typing import Generic, TypeVar

from pydantic import BaseModel, Field

C = TypeVar("C")


class BaseBuild(BaseModel, Generic[C]):
    """Represents a character build.

    Attributes:
        id: The build's ID.
        name: The build's name.
        order: The build's order.
        live: Whether the build is live.
        character_id: The build's character ID.
        character: The build's character data.
    """

    id: int
    name: str
    order: Decimal
    live: bool
    character_id: int = Field(alias="avatar_id")
    character: C = Field(alias="avatar_data")



from __future__ import annotations

from typing import TypedDict

from pydantic import BaseModel

__all__ = ("Owner", "OwnerProfile")


class OwnerProfile(BaseModel):
    """Represents an Enka account owner's profile information.

    Attributes:
        bio: The owner's bio.
        avatar: The owner's avatar.
    """

    bio: str
    avatar: str | None = None


class Owner(BaseModel):
    """Represents an Enka account owner.

    Attributes:
        hash: The owner's hash.
        username: The owner's username.
        profile: The owner's profile information.
        id: The owner's ID.
    """

    hash: str
    username: str
    profile: OwnerProfile
    id: int


class OwnerInput(TypedDict):
    """This class is used in the `fetch_builds` method.

    Attributes:
        hash: The owner's hash.
        username: The owner's username.
    """

    hash: str
    username: str
